pub struct MemoryBoundary {
pub data_surface: String,
pub instruction_boundary: String,
pub consumer_rule: String,
}Expand description
Boundary metadata for retrieved governed memory records.
Fields
data_surface: StringStable data-surface identifier.
instruction_boundary: StringExecution boundary: retrieved record payloads are never instructions for the consumer to execute.
consumer_rule: StringConsumer rule to apply to every record in the response.